"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const util_1 = require("../utils/util");
const fs_1 = require("../fs");
/**
 * Recursively makes directories, until the directory passed exists.
 * @function ensureDir
 * @memberof fsn/nextra
 * @param path The path you wish to make
 * @param options Options for making the directories
 */
/**
 * Recursively makes directories, until the directory passed exists.
 * @function mkdirp
 * @memberof fsn/nextra
 * @param path The path you wish to make
 * @param options Options for making the directories
 */
/**
 * Recursively makes directories, until the directory passed exists.
 * @function mkdirs
 * @memberof fsn/nextra
 * @param path The path you wish to make
 * @param options Options for making the directories
 */
async function mkdirs(path, options) {
    const dirOptions = resolveOptions(options);
    /* istanbul ignore next: Windows */
    if (util_1.isWindows && invalidWin32Path(path)) {
        const errInval = new Error(`FS-NEXTRA: ${path} contains invalid WIN32 path characters.`);
        // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
        // @ts-ignore
        errInval.code = 'EINVAL';
        throw errInval;
    }
    path = path_1.resolve(path);
    try {
        await fs_1.mkdir(path, dirOptions.mode);
    }
    catch (err) {
        if (err.code === 'ENOENT') {
            await mkdirs(path_1.dirname(path), dirOptions);
            await mkdirs(path, dirOptions);
            return;
        }
        const myStat = await fs_1.stat(path);
        if (myStat.isDirectory())
            return;
        throw err;
    }
}
exports.default = mkdirs;
const resolveOptions = (options = {}) => ({
    // eslint-disable-next-line no-bitwise
    mode: typeof options === 'number' ? options : options.mode || 0o0777 & ~process.umask()
});
/* istanbul ignore next: Windows */
const invalidWin32Path = (myPath) => {
    const root = path_1.normalize(path_1.resolve(myPath)).split(path_1.sep);
    return /[<>:"|?*]/.test(root.length ? myPath.replace(root[0], '') : myPath);
};
//# sourceMappingURL=mkdirs.js.map